@@ -33,11 +33,12 @@ public:
         Command = 2
     };
 
-    AbstractBookmarkItem(AbstractBookmarkItem* parent = 0)
+    AbstractBookmarkItem(ItemType type, AbstractBookmarkItem* parent = nullptr)
+        : m_type(type),
+          m_parent(parent)
     {
-        m_parent = parent;
     }
-    ~AbstractBookmarkItem()
+    virtual ~AbstractBookmarkItem()
     {
         qDeleteAll(m_children);
     }
@@ -72,9 +73,8 @@ class BookmarkRootItem : public AbstractBookmarkItem
 {
 public:
     BookmarkRootItem()
-        : AbstractBookmarkItem()
+        : AbstractBookmarkItem(AbstractBookmarkItem::Root)
     {
-        m_type = AbstractBookmarkItem::Root;
         m_value = m_display = QStringLiteral("root");
     }
 };
@@ -83,9 +83,8 @@ class BookmarkCommandItem : public AbstractBookmarkItem
 {
 public:
     BookmarkCommandItem(const QString &name, const QString &command, AbstractBookmarkItem *parent)
-        : AbstractBookmarkItem(parent)
+        : AbstractBookmarkItem(AbstractBookmarkItem::Command, parent)
     {
-        m_type = AbstractBookmarkItem::Command;
         m_value = command;
         m_display = name;
     }
@@ -96,9 +95,8 @@ class BookmarkGroupItem : public AbstractBookmarkItem
 {
 public:
     BookmarkGroupItem(const QString &name, AbstractBookmarkItem *parent)
-        : AbstractBookmarkItem(parent)
+        : AbstractBookmarkItem(AbstractBookmarkItem::Group, parent)
     {
-        m_type = AbstractBookmarkItem::Group;
         m_display = name;
     }
 };
@@ -170,7 +168,7 @@ public:
         QFile f(fname);
         if (!f.open(QIODevice::ReadOnly))
         {
-            qDebug() << "Canot open file" << fname;
+            //qDebug() << "Cannot open file" << fname;
             // TODO/FIXME: message box
             return;
         }
@@ -240,7 +238,7 @@ public:
 
 BookmarksModel::BookmarksModel(QObject *parent)
     : QAbstractItemModel(parent),
-      m_root(0)
+      m_root(nullptr)
 {
     setup();
 }
