@@ -17,9 +17,10 @@
  ***************************************************************************/
 
 #include <QDockWidget>
-#include <QDesktopWidget>
+#include <QScreen>
 #include <QToolButton>
 #include <QMessageBox>
+#include <QStandardPaths>
 #include <QTimer>
 #include <functional>
 
@@ -180,7 +181,7 @@ void MainWindow::enableDropMode()
     realign();
 }
 
-void MainWindow::setDropShortcut(QKeySequence dropShortCut)
+void MainWindow::setDropShortcut(const QKeySequence& dropShortCut)
 {
     if (!m_dropMode)
         return;
@@ -531,8 +532,18 @@ void MainWindow::setup_ViewMenu_Actions()
 
 void MainWindow::setupCustomDirs()
 {
+    const QString appName = QCoreApplication::applicationName();
+    QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, appName,
+                                                       QStandardPaths::LocateDirectory);
+
+    dirs.removeDuplicates(); // QStandardPaths::locateAll() produces duplicates
+
+    for (const QString& dir : qAsConst(dirs)) {
+        TermWidgetImpl::addCustomColorSchemeDir(dir + QLatin1String("/color-schemes"));
+    }
+    // FIXME: To be deprecated and then removed
     const QSettings settings;
-    const QString dir = QFileInfo(settings.fileName()).canonicalPath() + QStringLiteral("/color-schemes/");
+    const QString dir = QFileInfo(settings.fileName()).canonicalPath() + QLatin1String("/color-schemes");
     TermWidgetImpl::addCustomColorSchemeDir(dir);
 }
 
@@ -676,8 +687,7 @@ void MainWindow::propertiesChanged()
         for (auto& action : menuBarActions)
         {
             QString txt = action->text();
-            txt.remove(QRegularExpression(QStringLiteral("\\s*\\(&[a-zA-Z0-9]\\)\\s*"))); // Chinese and Japanese
-            txt.remove(QLatin1Char('&')); // other languages
+            Properties::removeAccelerator(txt);
             action->setText(txt);
         }
     }
@@ -711,16 +721,19 @@ void MainWindow::realign()
 {
     if (m_dropMode)
     {
-        QRect desktop = QApplication::desktop()->availableGeometry(this);
-        QRect geometry = QRect(0, 0,
-                               desktop.width()  * Properties::Instance()->dropWidht  / 100,
-                               desktop.height() * Properties::Instance()->dropHeight / 100
-            );
-        geometry.moveCenter(desktop.center());
+        QScreen *appScreen = QGuiApplication::screenAt(QCursor::pos());
+        if(appScreen == nullptr)
+            appScreen = QGuiApplication::primaryScreen();
+        const QRect desktop = appScreen->availableGeometry();
+        QRect g = QRect(desktop.x(),
+                        desktop.y(),
+                        desktop.width()  * Properties::Instance()->dropWidht  / 100,
+                        desktop.height() * Properties::Instance()->dropHeight / 100);
+        g.moveCenter(desktop.center());
         // do not use 0 here - we need to calculate with potential panel on top
-        geometry.setTop(desktop.top());
-        if (geometry != this->geometry()) {
-            setGeometry(geometry);
+        g.setTop(desktop.top());
+        if (g != geometry()) {
+            setGeometry(g);
         }
     }
 }
