@@ -17,14 +17,14 @@
  ***************************************************************************/
 
 #include <qtermwidget.h>
-#include <assert.h>
+#include <cassert>
 
 #include "properties.h"
 #include "config.h"
 #include "mainwindow.h"
 #include "qterminalapp.h"
 
-Properties * Properties::m_instance = 0;
+Properties * Properties::m_instance = nullptr;
 
 
 Properties * Properties::Instance(const QString& filename)
@@ -41,14 +41,14 @@ Properties::Properties(const QString& filename)
         m_settings = new QSettings();
     else
         m_settings = new QSettings(filename);
-    qDebug("Properties constructor called");
+    //qDebug("Properties constructor called");
 }
 
 Properties::~Properties()
 {
-    qDebug("Properties destructor called");
+    //qDebug("Properties destructor called");
     delete m_settings;
-    m_instance = 0;
+    m_instance = nullptr;
 }
 
 QFont Properties::defaultFont()
@@ -77,6 +77,7 @@ void Properties::loadSettings()
     font = qvariant_cast<QFont>(m_settings->value(QLatin1String("font"), font));
 
     mainWindowSize = m_settings->value(QLatin1String("MainWindow/size")).toSize();
+    fixedWindowSize = m_settings->value(QLatin1String("MainWindow/fixedSize"), QSize(600, 400)).toSize().expandedTo(QSize(300, 200));
     mainWindowPosition = m_settings->value(QLatin1String("MainWindow/pos")).toPoint();
     mainWindowState = m_settings->value(QLatin1String("MainWindow/state")).toByteArray();
 
@@ -112,20 +113,26 @@ void Properties::loadSettings()
     hideTabBarWithOneTab = m_settings->value(QLatin1String("HideTabBarWithOneTab"), false).toBool();
     m_motionAfterPaste = m_settings->value(QLatin1String("MotionAfterPaste"), 0).toInt();
 
-    /* fixed tab width */
+    /* fixed tabs width */
     fixedTabWidth = m_settings->value(QLatin1String("FixedTabWidth"), true).toBool();
     fixedTabWidthValue = m_settings->value(QLatin1String("FixedTabWidthValue"), 500).toInt();
+    /* tabs features */
     showCloseTabButton = m_settings->value(QLatin1String("ShowCloseTabButton"), true).toBool();
+    closeTabOnMiddleClick = m_settings->value(QLatin1String("CloseTabOnMiddleClick"), true).toBool();
 
     /* toggles */
     borderless = m_settings->value(QLatin1String("Borderless"), false).toBool();
     tabBarless = m_settings->value(QLatin1String("TabBarless"), false).toBool();
     menuVisible = m_settings->value(QLatin1String("MenuVisible"), true).toBool();
+    boldIntense = m_settings->value(QLatin1String("BoldIntense"), true).toBool();
+    noMenubarAccel = m_settings->value(QLatin1String("NoMenubarAccel"), true).toBool();
     askOnExit = m_settings->value(QLatin1String("AskOnExit"), true).toBool();
     saveSizeOnExit = m_settings->value(QLatin1String("SaveSizeOnExit"), true).toBool();
     savePosOnExit = m_settings->value(QLatin1String("SavePosOnExit"), true).toBool();
     useCWD = m_settings->value(QLatin1String("UseCWD"), false).toBool();
+    m_openNewTabRightToActiveTab = m_settings->value(QLatin1String("OpenNewTabRightToActiveTab"), false).toBool();
     term = m_settings->value(QLatin1String("Term"), QLatin1String("xterm-256color")).toString();
+    handleHistoryCommand = m_settings->value(QLatin1String("HandleHistory")).toString();
 
     // bookmarks
     useBookmarks = m_settings->value(QLatin1String("UseBookmarks"), false).toBool();
@@ -146,11 +153,14 @@ void Properties::loadSettings()
     changeWindowTitle = m_settings->value(QLatin1String("ChangeWindowTitle"), true).toBool();
     changeWindowIcon = m_settings->value(QLatin1String("ChangeWindowIcon"), true).toBool();
     enabledBidiSupport = m_settings->value(QLatin1String("enabledBidiSupport"), true).toBool();
+    useFontBoxDrawingChars = m_settings->value(QLatin1String("UseFontBoxDrawingChars"), false).toBool();
 
     confirmMultilinePaste = m_settings->value(QLatin1String("ConfirmMultilinePaste"), false).toBool();
     trimPastedTrailingNewlines = m_settings->value(QLatin1String("TrimPastedTrailingNewlines"), false).toBool();
 
     windowMaximized = m_settings->value(QLatin1String("LastWindowMaximized"), false).toBool();
+
+    prefDialogSize = m_settings->value(QLatin1String("PrefDialogSize")).toSize();
 }
 
 void Properties::saveSettings()
@@ -166,7 +176,7 @@ void Properties::saveSettings()
 
     m_settings->beginGroup(QLatin1String("Shortcuts"));
     MainWindow *mainWindow = QTerminalApp::Instance()->getWindowList()[0];
-    assert(mainWindow != NULL);
+    assert(mainWindow != nullptr);
 
     QMapIterator< QString, QAction * > it(mainWindow->leaseActions());
     while( it.hasNext() )
@@ -181,6 +191,7 @@ void Properties::saveSettings()
     m_settings->endGroup();
 
     m_settings->setValue(QLatin1String("MainWindow/size"), mainWindowSize);
+    m_settings->setValue(QLatin1String("MainWindow/fixedSize"), fixedWindowSize);
     m_settings->setValue(QLatin1String("MainWindow/pos"), mainWindowPosition);
     m_settings->setValue(QLatin1String("MainWindow/state"), mainWindowState);
 
@@ -216,15 +227,20 @@ void Properties::saveSettings()
     m_settings->setValue(QLatin1String("FixedTabWidth"), fixedTabWidth);
     m_settings->setValue(QLatin1String("FixedTabWidthValue"), fixedTabWidthValue);
     m_settings->setValue(QLatin1String("ShowCloseTabButton"), showCloseTabButton);
+    m_settings->setValue(QLatin1String("CloseTabOnMiddleClick"), closeTabOnMiddleClick);
 
     m_settings->setValue(QLatin1String("Borderless"), borderless);
     m_settings->setValue(QLatin1String("TabBarless"), tabBarless);
+    m_settings->setValue(QLatin1String("BoldIntense"), boldIntense);
+    m_settings->setValue(QLatin1String("NoMenubarAccel"), noMenubarAccel);
     m_settings->setValue(QLatin1String("MenuVisible"), menuVisible);
     m_settings->setValue(QLatin1String("AskOnExit"), askOnExit);
     m_settings->setValue(QLatin1String("SavePosOnExit"), savePosOnExit);
     m_settings->setValue(QLatin1String("SaveSizeOnExit"), saveSizeOnExit);
     m_settings->setValue(QLatin1String("UseCWD"), useCWD);
+    m_settings->setValue(QLatin1String("OpenNewTabRightToActiveTab"), m_openNewTabRightToActiveTab);
     m_settings->setValue(QLatin1String("Term"), term);
+    m_settings->setValue(QLatin1String("HandleHistory"), handleHistoryCommand);
 
     // bookmarks
     m_settings->setValue(QLatin1String("UseBookmarks"), useBookmarks);
@@ -244,11 +260,38 @@ void Properties::saveSettings()
     m_settings->setValue(QLatin1String("ChangeWindowTitle"), changeWindowTitle);
     m_settings->setValue(QLatin1String("ChangeWindowIcon"), changeWindowIcon);
     m_settings->setValue(QLatin1String("enabledBidiSupport"), enabledBidiSupport);
+    m_settings->setValue(QLatin1String("UseFontBoxDrawingChars"), useFontBoxDrawingChars);
 
     m_settings->setValue(QLatin1String("ConfirmMultilinePaste"), confirmMultilinePaste);
     m_settings->setValue(QLatin1String("TrimPastedTrailingNewlines"), trimPastedTrailingNewlines);
 
     m_settings->setValue(QLatin1String("LastWindowMaximized"), windowMaximized);
+
+    m_settings->setValue(QLatin1String("PrefDialogSize"), prefDialogSize);
+}
+
+int Properties::versionComparison(const QString &v1, const QString &v2)
+{
+    int res = 0;
+    QStringList list1 = v1.split(QLatin1String("."));
+    QStringList list2 = v2.split(QLatin1String("."));
+    int N = qMin(list1.size(), list2.size());
+    for (int i = 0; i < N; ++i)
+    {
+        int n1 = list1.at(i).toInt();
+        int n2 = list2.at(i).toInt();
+        if (n1 != n2)
+        {
+            if (n1 < n2)
+                res = -1;
+            else
+                res = 1;
+            break;
+        }
+    }
+    if (res == 0 && list1.size() > list2.size())
+        res = -1;
+    return res;
 }
 
 void Properties::migrate_settings()
@@ -259,13 +302,13 @@ void Properties::migrate_settings()
     QSettings settings;
     QString lastVersion = settings.value(QLatin1String("version"), QLatin1String("0.0.0")).toString();
     QString currentVersion(QLatin1String(QTERMINAL_VERSION));
-    if (currentVersion < lastVersion)
+    if (versionComparison(currentVersion, lastVersion) < 0)
     {
         qDebug() << "Warning: Configuration file was written by a newer version "
-                 << "of QTerminal. Some settings might be incompatible";
+                 << "of QTerminal. Some settings might be incompatible.";
     }
 
-    if (lastVersion < QLatin1String("0.4.0"))
+    if (versionComparison(lastVersion, QLatin1String("0.4.0")) < 0)
     {
         // ===== Paste Selection -> Paste Clipboard =====
         settings.beginGroup(QLatin1String("Shortcuts"));
@@ -278,7 +321,7 @@ void Properties::migrate_settings()
         settings.endGroup();
     }
 
-    if (lastVersion <= QLatin1String("0.6.0"))
+    if (versionComparison(lastVersion, QLatin1String("0.6.0")) <= 0)
     {
         // ===== AlwaysShowTabs -> HideTabBarWithOneTab =====
         if(!settings.contains(QLatin1String("HideTabBarWithOneTab")))
@@ -311,19 +354,27 @@ void Properties::migrate_settings()
             settings.setValue(QLatin1String("TerminalTransparency"), 100 - termOpacityValue);
         }
         settings.remove(QLatin1String("termOpacity"));
-	// geometry -> size, pos
-    if (!settings.contains(QLatin1String("MainWindow/size")))
-	{
-	    QWidget geom;
-        geom.restoreGeometry(settings.value(QLatin1String("MainWindow/geometry")).toByteArray());
+        // geometry -> size, pos
+        if (!settings.contains(QLatin1String("MainWindow/size")) && settings.contains(QLatin1String("MainWindow/geometry")))
+        {
+            QWidget geom;
+            geom.restoreGeometry(settings.value(QLatin1String("MainWindow/geometry")).toByteArray());
             settings.setValue(QLatin1String("MainWindow/size"), geom.size());
             settings.setValue(QLatin1String("MainWindow/pos"), geom.pos());
             settings.setValue(QLatin1String("MainWindow/isMaximized"), geom.isMaximized());
             settings.remove(QLatin1String("MainWindow/geometry"));
-	}
+        }
     }
 
     if (currentVersion > lastVersion)
         settings.setValue(QLatin1String("version"), currentVersion);
 }
 
+void Properties::removeAccelerator(QString& str)
+{
+    // Chinese, Japanese,...
+    str.remove(QRegularExpression(QStringLiteral("\\s*\\(&[a-zA-Z0-9]\\)\\s*")));
+    // other languages
+    str.remove(QLatin1Char('&'));
+}
+
