@@ -41,7 +41,11 @@ class Properties
         void loadSettings();
         void migrate_settings();
 
+        static void removeAccelerator(QString& str);
+
         QSize mainWindowSize;
+        QSize fixedWindowSize;
+        QSize prefDialogSize;
         QPoint mainWindowPosition;
         QByteArray mainWindowState;
         //ShortcutMap shortcuts;
@@ -74,9 +78,13 @@ class Properties
         int fixedTabWidthValue;
 
         bool showCloseTabButton;
+        bool closeTabOnMiddleClick;
+
+        bool boldIntense;
 
         bool borderless;
         bool tabBarless;
+        bool noMenubarAccel;
         bool menuVisible;
 
         bool askOnExit;
@@ -85,9 +93,12 @@ class Properties
         bool savePosOnExit;
 
         bool useCWD;
+        bool m_openNewTabRightToActiveTab;
 
         QString term;
 
+        QString handleHistoryCommand;
+
         bool useBookmarks;
         bool bookmarksVisible;
         QString bookmarksFile;
@@ -109,15 +120,19 @@ class Properties
 
         bool windowMaximized;
 
-
+        bool useFontBoxDrawingChars;
     private:
 
+        Properties(const Properties &) = delete;
+        Properties &operator=(const Properties &) = delete;
+
+        int versionComparison(const QString &v1, const QString &v2);
+
         // Singleton handling
         static Properties *m_instance;
         QString filename;
 
         explicit Properties(const QString& filename);
-        Properties(const Properties &) {};
 
         QSettings *m_settings;
 
