@@ -30,6 +30,14 @@
 #include "config.h"
 #include "qterminalapp.h"
 
+void KeySequenceEdit::keyPressEvent(QKeyEvent* event)
+{
+    // by not allowing multiple shortcuts,
+    // the Qt bug that makes Meta a non-modifier is worked around
+    clear();
+    QKeySequenceEdit::keyPressEvent(event);
+}
+
 Delegate::Delegate (QObject *parent)
     : QStyledItemDelegate (parent)
 {
@@ -152,10 +160,12 @@ PropertiesDialog::PropertiesDialog(QWidget *parent)
     tabsPos_comboBox->addItems(tabsPosList);
     tabsPos_comboBox->setCurrentIndex(Properties::Instance()->tabsPos);
 
-    /* tab width */
+    /* fixed tabs width */
     fixedTabWidthCheckBox->setChecked(Properties::Instance()->fixedTabWidth);
     fixedTabWidthSpinBox->setValue(Properties::Instance()->fixedTabWidthValue);
+    /* tabs features */
     closeTabButtonCheckBox->setChecked(Properties::Instance()->showCloseTabButton);
+    closeTabOnMiddleClickCheckBox->setChecked(Properties::Instance()->closeTabOnMiddleClick);
 
     /* keyboard cursor shape */
     QStringList keyboardCursorShapeList;
@@ -165,6 +175,9 @@ PropertiesDialog::PropertiesDialog(QWidget *parent)
 
     hideTabBarCheckBox->setChecked(Properties::Instance()->hideTabBarWithOneTab);
 
+    // bold font face for intense colors
+    boldIntenseCheckBox->setChecked(Properties::Instance()->boldIntense);
+
     // main menu bar
     menuAccelCheckBox->setChecked(Properties::Instance()->noMenubarAccel);
     showMenuCheckBox->setChecked(Properties::Instance()->menuVisible);
@@ -206,6 +219,7 @@ PropertiesDialog::PropertiesDialog(QWidget *parent)
     fixedHeightSpinBox->setValue(Properties::Instance()->fixedWindowSize.height());
 
     useCwdCheckBox->setChecked(Properties::Instance()->useCWD);
+    openNewTabRightToActiveTabCheckBox->setChecked(Properties::Instance()->m_openNewTabRightToActiveTab);
 
     termComboBox->setCurrentText(Properties::Instance()->term);
 
@@ -298,6 +312,7 @@ void PropertiesDialog::apply()
     Properties::Instance()->prefDialogSize = size();
 
     Properties::Instance()->useCWD = useCwdCheckBox->isChecked();
+    Properties::Instance()->m_openNewTabRightToActiveTab = openNewTabRightToActiveTabCheckBox->isChecked();
 
     Properties::Instance()->term = termComboBox->currentText();
     Properties::Instance()->handleHistoryCommand = handleHistoryLineEdit->text();
@@ -308,7 +323,9 @@ void PropertiesDialog::apply()
     Properties::Instance()->fixedTabWidthValue = fixedTabWidthSpinBox->value();
     Properties::Instance()->keyboardCursorShape = keybCursorShape_comboBox->currentIndex();
     Properties::Instance()->showCloseTabButton = closeTabButtonCheckBox->isChecked();
+    Properties::Instance()->closeTabOnMiddleClick = closeTabOnMiddleClickCheckBox->isChecked();
     Properties::Instance()->hideTabBarWithOneTab = hideTabBarCheckBox->isChecked();
+    Properties::Instance()->boldIntense = boldIntenseCheckBox->isChecked();
     Properties::Instance()->noMenubarAccel = menuAccelCheckBox->isChecked();
     Properties::Instance()->menuVisible = showMenuCheckBox->isChecked();
     Properties::Instance()->borderless = borderlessCheckBox->isChecked();
@@ -379,17 +396,22 @@ void PropertiesDialog::saveShortcuts()
 
     for( int x=0; x < shortcutCount; x++ )
     {
-        QString keyValue = shortcutKeys.at(x);
+        const QString& keyValue = shortcutKeys.at(x);
         QAction *keyAction = actions[keyValue];
 
-        QTableWidgetItem *item = shortcutsWidget->item(x, 1);
-        QKeySequence sequence = QKeySequence(item->text());
-        QString sequenceString = sequence.toString();
+        QTableWidgetItem *item = nullptr;
+        QString txt = keyAction->text();
+        Properties::removeAccelerator(txt);
+        auto items = shortcutsWidget->findItems(txt, Qt::MatchExactly);
+        if (!items.isEmpty())
+            item = shortcutsWidget->item(shortcutsWidget->row(items.at(0)), 1);
+        if (item == nullptr)
+            continue;
 
         QList<QKeySequence> shortcuts;
         const auto sequences = item->text().split(QLatin1Char('|'));
-        for (const QKeySequence& sequenceString : sequences)
-            shortcuts.append(QKeySequence(sequenceString));
+        for (const QString& sequenceString : sequences)
+            shortcuts.append(QKeySequence(sequenceString, QKeySequence::NativeText));
         keyAction->setShortcuts(shortcuts);
     }
     Properties::Instance()->saveSettings();
@@ -397,6 +419,8 @@ void PropertiesDialog::saveShortcuts()
 
 void PropertiesDialog::setupShortcuts()
 {
+    shortcutsWidget->setSortingEnabled(false);
+
     QMap<QString, QAction*> actions = QTerminalApp::Instance()->getWindowList()[0]->leaseActions();
     QList< QString > shortcutKeys = actions.keys();
     int shortcutCount = shortcutKeys.count();
@@ -405,15 +429,17 @@ void PropertiesDialog::setupShortcuts()
 
     for( int x=0; x < shortcutCount; x++ )
     {
-        QString keyValue = shortcutKeys.at(x);
+        const QString& keyValue = shortcutKeys.at(x);
         QAction *keyAction = actions[keyValue];
         QStringList sequenceStrings;
 
         const auto shortcuts = keyAction->shortcuts();
         for (const QKeySequence &shortcut : shortcuts)
-            sequenceStrings.append(shortcut.toString());
+            sequenceStrings.append(shortcut.toString(QKeySequence::NativeText));
 
-        QTableWidgetItem *itemName = new QTableWidgetItem( tr(keyValue.toStdString().c_str()) );
+        QString txt = keyAction->text();
+        Properties::removeAccelerator(txt);
+        QTableWidgetItem *itemName = new QTableWidgetItem(txt);
         QTableWidgetItem *itemShortcut = new QTableWidgetItem( sequenceStrings.join(QLatin1Char('|')) );
 
         itemName->setFlags( itemName->flags() & ~Qt::ItemIsEditable & ~Qt::ItemIsSelectable );
@@ -424,6 +450,8 @@ void PropertiesDialog::setupShortcuts()
 
     shortcutsWidget->resizeColumnsToContents();
 
+    shortcutsWidget->setSortingEnabled(true);
+
     // No shortcut validation is needed with QKeySequenceEdit.
 }
 
