@@ -41,7 +41,7 @@ class TabWidget : public QTabWidget
 {
 Q_OBJECT
 public:
-    TabWidget(QWidget* parent = 0);
+    TabWidget(QWidget* parent = nullptr);
     ~TabWidget() override;
 
     TermWidgetHolder * terminalHolder();
@@ -53,6 +53,7 @@ public slots:
     int addNewTab(TerminalConfig cfg);
     void removeTab(int);
     void switchTab(int);
+    void onAction();
     void saveCurrentChanged(int);
     void removeCurrentTab();
     int switchToRight();
@@ -104,22 +105,23 @@ signals:
 
 protected:
     enum Direction{Left = 1, Right};
-    void contextMenuEvent(QContextMenuEvent * event);
+    void contextMenuEvent(QContextMenuEvent * event) override;
     void move(Direction);
     /*! Event filter for TabWidget's QTabBar. It's installed on tabBar()
         in the constructor.
         It's purpose is to handle doubleclicks on QTabBar for session
         renaming or new tab opening
      */
-    bool eventFilter(QObject *obj, QEvent *event);
+    bool eventFilter(QObject *obj, QEvent *event) override;
 protected slots:
     void updateTabIndices();
-    void onTermTitleChanged(QString title, QString icon);
+    void onTermTitleChanged(const QString& title, const QString& icon);
 
 private:
     int tabNumerator;
     /* re-order naming of the tabs then removeCurrentTab() */
     void renameTabsAfterRemove();
+    int switchTo(int index);
 
     TabBar *mTabBar;
     QScopedPointer<TabSwitcher> mSwitcher;
