@@ -101,6 +101,7 @@ void TermWidgetImpl::propertiesChanged()
     setTerminalBackgroundImage(Properties::Instance()->backgroundImage);
     setBidiEnabled(Properties::Instance()->enabledBidiSupport);
     setDrawLineChars(!Properties::Instance()->useFontBoxDrawingChars);
+    setBoldIntense(Properties::Instance()->boldIntense);
 
     /* be consequent with qtermwidget.h here */
     switch(Properties::Instance()->scrollBarPos) {
@@ -169,7 +170,7 @@ void TermWidgetImpl::customContextMenuCall(const QPoint & pos)
 
 void TermWidgetImpl::zoomIn()
 {
-    emit QTermWidget::zoomIn();
+    QTermWidget::zoomIn();
 // note: do not save zoom here due the #74 Zoom reset option resets font back to Monospace
 //    Properties::Instance()->font = getTerminalFont();
 //    Properties::Instance()->saveSettings();
@@ -177,7 +178,7 @@ void TermWidgetImpl::zoomIn()
 
 void TermWidgetImpl::zoomOut()
 {
-    emit QTermWidget::zoomOut();
+    QTermWidget::zoomOut();
 // note: do not save zoom here due the #74 Zoom reset option resets font back to Monospace
 //    Properties::Instance()->font = getTerminalFont();
 //    Properties::Instance()->saveSettings();
@@ -237,7 +238,7 @@ void TermWidgetImpl::paste(QClipboard::Mode mode)
                 {
                     if (confirmation.buttonRole(btn) == QMessageBox::ActionRole && btn->text() == QMessageBox::tr("Show Details..."))
                     {
-                        btn->clicked();
+                        Q_EMIT btn->clicked();
                         break;
                     }
                 }
@@ -368,7 +369,7 @@ void TermWidget::closeTerminal()
     holder->splitCollapse(this);
 }
 
-void TermWidget::sendText(const QString text)
+void TermWidget::sendText(const QString& text)
 {
     if (impl())
     {
