@@ -34,7 +34,7 @@ class TermWidgetImpl : public QTermWidget
 
     public:
 
-        TermWidgetImpl(TerminalConfig &cfg, QWidget * parent=0);
+        TermWidgetImpl(TerminalConfig &cfg, QWidget * parent=nullptr);
         void propertiesChanged();
         void paste(QClipboard::Mode mode);
 
@@ -64,9 +64,9 @@ class TermWidget : public QWidget, public DBusAddressable
     QColor m_border;
 
     public:
-        TermWidget(TerminalConfig &cfg, QWidget * parent=0);
+        TermWidget(TerminalConfig &cfg, QWidget * parent=nullptr);
 
-        void propertiesChanged(); 
+        void propertiesChanged();
         QStringList availableKeyBindings() { return m_term->availableKeyBindings(); }
 
         TermWidgetImpl * impl() { return m_term; }
@@ -75,7 +75,7 @@ class TermWidget : public QWidget, public DBusAddressable
         QDBusObjectPath splitHorizontal(const QHash<QString,QVariant> &termArgs);
         QDBusObjectPath splitVertical(const QHash<QString,QVariant> &termArgs);
         QDBusObjectPath getTab();
-        void sendText(const QString text);
+        void sendText(const QString& text);
         void closeTerminal();
         #endif
 
@@ -92,7 +92,11 @@ class TermWidget : public QWidget, public DBusAddressable
     public slots:
 
     protected:
-        void paintEvent (QPaintEvent * event);
+        bool focusNextPrevChild(bool) override {
+            // prevent focus change with Tab and, especially, Backtab
+            return false;
+        }
+        void paintEvent (QPaintEvent * event) override;
         bool eventFilter(QObject * obj, QEvent * evt) override;
 
     private slots:
